@@ -1,19 +1,17 @@
+from omnitools import sha3_512hd, b64d_and_utf8d, jl, jd_and_b64e
+from typing import Dict
 import keyring
-from omnitools import sha512, b64d_and_utf8d, jl, jd_and_b64e
-from typing import *
 
 
 __ALL__ = ["Broker"]
 
 
 class Broker(object):
-    def __init__(self, app_name: str, username: str) -> None:
-        self.__split_length = 10 ** 3
-        self.__krs = lambda i, v: keyring.set_password(sha512(f"{app_name}[{i}]"), username, v)
-        self.__krg = lambda i: keyring.get_password(sha512(f"{app_name}[{i}]"), username)
-        self.__krd = lambda i: keyring.delete_password(sha512(f"{app_name}[{i}]"), username)
-        self.__app_name = app_name
-        self.__username = username
+    def __init__(self, *, app_name: str, username: str, split_length: int = 10 ** 3) -> None:
+        self.__split_length = split_length
+        self.__krs = lambda i, v: keyring.set_password(sha3_512hd("{}[{}]".format(app_name, i)), username, v)
+        self.__krg = lambda i: keyring.get_password(sha3_512hd("{}[{}]".format(app_name, i)), username)
+        self.__krd = lambda i: keyring.delete_password(sha3_512hd("{}[{}]".format(app_name, i)), username)
         if len(self.__get()) == 0:
             self.set("", "")
 
@@ -74,8 +72,9 @@ class Broker(object):
 
     def destroy(self) -> bool:
         self.__delete()
-        self.__username = None
-        self.__app_name = None
+        self.__krs = None
+        self.__krg = None
+        self.__krd = None
         return True
 
 
